==> zio-aws-comprehend_2.13-5.17.208.2-sources.jar: zio/aws/comprehend/model/CreateDocumentClassifierRequest.scala <==
package zio.aws.comprehend.model
import zio.aws.comprehend.model.primitives.{
  ComprehendArnName,
  ClientRequestTokenString,
  IamRoleArn,
  Policy,
  KmsKeyId,
  VersionName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateDocumentClassifierRequest(
    documentClassifierName: ComprehendArnName,
    versionName: Optional[VersionName] = Optional.Absent,
    dataAccessRoleArn: IamRoleArn,
    tags: Optional[Iterable[zio.aws.comprehend.model.Tag]] = Optional.Absent,
    inputDataConfig: zio.aws.comprehend.model.DocumentClassifierInputDataConfig,
    outputDataConfig: Optional[
      zio.aws.comprehend.model.DocumentClassifierOutputDataConfig
    ] = Optional.Absent,
    clientRequestToken: Optional[ClientRequestTokenString] = Optional.Absent,
    languageCode: zio.aws.comprehend.model.LanguageCode,
    volumeKmsKeyId: Optional[KmsKeyId] = Optional.Absent,
    vpcConfig: Optional[zio.aws.comprehend.model.VpcConfig] = Optional.Absent,
    mode: Optional[zio.aws.comprehend.model.DocumentClassifierMode] =
      Optional.Absent,
    modelKmsKeyId: Optional[KmsKeyId] = Optional.Absent,
    modelPolicy: Optional[Policy] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest = {
    import CreateDocumentClassifierRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest
      .builder()
      .documentClassifierName(
        ComprehendArnName.unwrap(documentClassifierName): java.lang.String
      )
      .optionallyWith(
        versionName.map(value => VersionName.unwrap(value): java.lang.String)
      )(_.versionName)
      .dataAccessRoleArn(IamRoleArn.unwrap(dataAccessRoleArn): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .inputDataConfig(inputDataConfig.buildAwsValue())
      .optionallyWith(outputDataConfig.map(value => value.buildAwsValue()))(
        _.outputDataConfig
      )
      .optionallyWith(
        clientRequestToken.map(value =>
          ClientRequestTokenString.unwrap(value): java.lang.String
        )
      )(_.clientRequestToken)
      .languageCode(languageCode.unwrap)
      .optionallyWith(
        volumeKmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.volumeKmsKeyId)
      .optionallyWith(vpcConfig.map(value => value.buildAwsValue()))(
        _.vpcConfig
      )
      .optionallyWith(mode.map(value => value.unwrap))(_.mode)
      .optionallyWith(
        modelKmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.modelKmsKeyId)
      .optionallyWith(
        modelPolicy.map(value => Policy.unwrap(value): java.lang.String)
      )(_.modelPolicy)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.CreateDocumentClassifierRequest.ReadOnly =
    zio.aws.comprehend.model.CreateDocumentClassifierRequest
      .wrap(buildAwsValue())
}
object CreateDocumentClassifierRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.CreateDocumentClassifierRequest =
      zio.aws.comprehend.model.CreateDocumentClassifierRequest(
        documentClassifierName,
        versionName.map(value => value),
        dataAccessRoleArn,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        inputDataConfig.asEditable,
        outputDataConfig.map(value => value.asEditable),
        clientRequestToken.map(value => value),
        languageCode,
        volumeKmsKeyId.map(value => value),
        vpcConfig.map(value => value.asEditable),
        mode.map(value => value),
        modelKmsKeyId.map(value => value),
        modelPolicy.map(value => value)
      )
    def documentClassifierName: ComprehendArnName
    def versionName: Optional[VersionName]
    def dataAccessRoleArn: IamRoleArn
    def tags: Optional[List[zio.aws.comprehend.model.Tag.ReadOnly]]
    def inputDataConfig
        : zio.aws.comprehend.model.DocumentClassifierInputDataConfig.ReadOnly
    def outputDataConfig: Optional[
      zio.aws.comprehend.model.DocumentClassifierOutputDataConfig.ReadOnly
    ]
    def clientRequestToken: Optional[ClientRequestTokenString]
    def languageCode: zio.aws.comprehend.model.LanguageCode
    def volumeKmsKeyId: Optional[KmsKeyId]
    def vpcConfig: Optional[zio.aws.comprehend.model.VpcConfig.ReadOnly]
    def mode: Optional[zio.aws.comprehend.model.DocumentClassifierMode]
    def modelKmsKeyId: Optional[KmsKeyId]
    def modelPolicy: Optional[Policy]
    def getDocumentClassifierName: ZIO[Any, Nothing, ComprehendArnName] =
      ZIO.succeed(documentClassifierName)
    def getVersionName: ZIO[Any, AwsError, VersionName] =
      AwsError.unwrapOptionField("versionName", versionName)
    def getDataAccessRoleArn: ZIO[Any, Nothing, IamRoleArn] =
      ZIO.succeed(dataAccessRoleArn)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.comprehend.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getInputDataConfig: ZIO[
      Any,
      Nothing,
      zio.aws.comprehend.model.DocumentClassifierInputDataConfig.ReadOnly
    ] = ZIO.succeed(inputDataConfig)
    def getOutputDataConfig: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.DocumentClassifierOutputDataConfig.ReadOnly
    ] = AwsError.unwrapOptionField("outputDataConfig", outputDataConfig)
    def getClientRequestToken: ZIO[Any, AwsError, ClientRequestTokenString] =
      AwsError.unwrapOptionField("clientRequestToken", clientRequestToken)
    def getLanguageCode
        : ZIO[Any, Nothing, zio.aws.comprehend.model.LanguageCode] =
      ZIO.succeed(languageCode)
    def getVolumeKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("volumeKmsKeyId", volumeKmsKeyId)
    def getVpcConfig
        : ZIO[Any, AwsError, zio.aws.comprehend.model.VpcConfig.ReadOnly] =
      AwsError.unwrapOptionField("vpcConfig", vpcConfig)
    def getMode
        : ZIO[Any, AwsError, zio.aws.comprehend.model.DocumentClassifierMode] =
      AwsError.unwrapOptionField("mode", mode)
    def getModelKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("modelKmsKeyId", modelKmsKeyId)
    def getModelPolicy: ZIO[Any, AwsError, Policy] =
      AwsError.unwrapOptionField("modelPolicy", modelPolicy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest
  ) extends zio.aws.comprehend.model.CreateDocumentClassifierRequest.ReadOnly {
    override val documentClassifierName: ComprehendArnName =
      zio.aws.comprehend.model.primitives
        .ComprehendArnName(impl.documentClassifierName())
    override val versionName: Optional[VersionName] = zio.aws.core.internal
      .optionalFromNullable(impl.versionName())
      .map(value => zio.aws.comprehend.model.primitives.VersionName(value))
    override val dataAccessRoleArn: IamRoleArn =
      zio.aws.comprehend.model.primitives.IamRoleArn(impl.dataAccessRoleArn())
    override val tags: Optional[List[zio.aws.comprehend.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.comprehend.model.Tag.wrap(item)
          }.toList
        )
    override val inputDataConfig
        : zio.aws.comprehend.model.DocumentClassifierInputDataConfig.ReadOnly =
      zio.aws.comprehend.model.DocumentClassifierInputDataConfig
        .wrap(impl.inputDataConfig())
    override val outputDataConfig: Optional[
      zio.aws.comprehend.model.DocumentClassifierOutputDataConfig.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.outputDataConfig())
      .map(value =>
        zio.aws.comprehend.model.DocumentClassifierOutputDataConfig.wrap(value)
      )
    override val clientRequestToken: Optional[ClientRequestTokenString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.clientRequestToken())
        .map(value =>
          zio.aws.comprehend.model.primitives.ClientRequestTokenString(value)
        )
    override val languageCode: zio.aws.comprehend.model.LanguageCode =
      zio.aws.comprehend.model.LanguageCode.wrap(impl.languageCode())
    override val volumeKmsKeyId: Optional[KmsKeyId] = zio.aws.core.internal
      .optionalFromNullable(impl.volumeKmsKeyId())
      .map(value => zio.aws.comprehend.model.primitives.KmsKeyId(value))
    override val vpcConfig
        : Optional[zio.aws.comprehend.model.VpcConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.vpcConfig())
        .map(value => zio.aws.comprehend.model.VpcConfig.wrap(value))
    override val mode
        : Optional[zio.aws.comprehend.model.DocumentClassifierMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.mode())
        .map(value =>
          zio.aws.comprehend.model.DocumentClassifierMode.wrap(value)
        )
    override val modelKmsKeyId: Optional[KmsKeyId] = zio.aws.core.internal
      .optionalFromNullable(impl.modelKmsKeyId())
      .map(value => zio.aws.comprehend.model.primitives.KmsKeyId(value))
    override val modelPolicy: Optional[Policy] = zio.aws.core.internal
      .optionalFromNullable(impl.modelPolicy())
      .map(value => zio.aws.comprehend.model.primitives.Policy(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest
  ): zio.aws.comprehend.model.CreateDocumentClassifierRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-comprehend_3-5.17.113.1-sources.jar: zio/aws/comprehend/model/CreateDocumentClassifierRequest.scala <==
package zio.aws.comprehend.model
import zio.aws.comprehend.model.primitives.{
  ComprehendArnName,
  ClientRequestTokenString,
  IamRoleArn,
  KmsKeyId,
  VersionName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateDocumentClassifierRequest(
    documentClassifierName: ComprehendArnName,
    versionName: Option[VersionName] = None,
    dataAccessRoleArn: IamRoleArn,
    tags: Option[Iterable[zio.aws.comprehend.model.Tag]] = None,
    inputDataConfig: zio.aws.comprehend.model.DocumentClassifierInputDataConfig,
    outputDataConfig: Option[
      zio.aws.comprehend.model.DocumentClassifierOutputDataConfig
    ] = None,
    clientRequestToken: Option[ClientRequestTokenString] = None,
    languageCode: zio.aws.comprehend.model.LanguageCode,
    volumeKmsKeyId: Option[KmsKeyId] = None,
    vpcConfig: Option[zio.aws.comprehend.model.VpcConfig] = None,
    mode: Option[zio.aws.comprehend.model.DocumentClassifierMode] = None,
    modelKmsKeyId: Option[KmsKeyId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest = {
    import CreateDocumentClassifierRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest
      .builder()
      .documentClassifierName(
        ComprehendArnName.unwrap(documentClassifierName): java.lang.String
      )
      .optionallyWith(
        versionName.map(value => VersionName.unwrap(value): java.lang.String)
      )(_.versionName)
      .dataAccessRoleArn(IamRoleArn.unwrap(dataAccessRoleArn): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .inputDataConfig(inputDataConfig.buildAwsValue())
      .optionallyWith(outputDataConfig.map(value => value.buildAwsValue()))(
        _.outputDataConfig
      )
      .optionallyWith(
        clientRequestToken.map(value =>
          ClientRequestTokenString.unwrap(value): java.lang.String
        )
      )(_.clientRequestToken)
      .languageCode(languageCode.unwrap)
      .optionallyWith(
        volumeKmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.volumeKmsKeyId)
      .optionallyWith(vpcConfig.map(value => value.buildAwsValue()))(
        _.vpcConfig
      )
      .optionallyWith(mode.map(value => value.unwrap))(_.mode)
      .optionallyWith(
        modelKmsKeyId.map(value => KmsKeyId.unwrap(value): java.lang.String)
      )(_.modelKmsKeyId)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.CreateDocumentClassifierRequest.ReadOnly =
    zio.aws.comprehend.model.CreateDocumentClassifierRequest
      .wrap(buildAwsValue())
}
object CreateDocumentClassifierRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.CreateDocumentClassifierRequest =
      zio.aws.comprehend.model.CreateDocumentClassifierRequest(
        documentClassifierName,
        versionName.map(value => value),
        dataAccessRoleArn,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        inputDataConfig.asEditable,
        outputDataConfig.map(value => value.asEditable),
        clientRequestToken.map(value => value),
        languageCode,
        volumeKmsKeyId.map(value => value),
        vpcConfig.map(value => value.asEditable),
        mode.map(value => value),
        modelKmsKeyId.map(value => value)
      )
    def documentClassifierName: ComprehendArnName
    def versionName: Option[VersionName]
    def dataAccessRoleArn: IamRoleArn
    def tags: Option[List[zio.aws.comprehend.model.Tag.ReadOnly]]
    def inputDataConfig
        : zio.aws.comprehend.model.DocumentClassifierInputDataConfig.ReadOnly
    def outputDataConfig: Option[
      zio.aws.comprehend.model.DocumentClassifierOutputDataConfig.ReadOnly
    ]
    def clientRequestToken: Option[ClientRequestTokenString]
    def languageCode: zio.aws.comprehend.model.LanguageCode
    def volumeKmsKeyId: Option[KmsKeyId]
    def vpcConfig: Option[zio.aws.comprehend.model.VpcConfig.ReadOnly]
    def mode: Option[zio.aws.comprehend.model.DocumentClassifierMode]
    def modelKmsKeyId: Option[KmsKeyId]
    def getDocumentClassifierName: ZIO[Any, Nothing, ComprehendArnName] =
      ZIO.succeed(documentClassifierName)
    def getVersionName: ZIO[Any, AwsError, VersionName] =
      AwsError.unwrapOptionField("versionName", versionName)
    def getDataAccessRoleArn: ZIO[Any, Nothing, IamRoleArn] =
      ZIO.succeed(dataAccessRoleArn)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.comprehend.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getInputDataConfig: ZIO[
      Any,
      Nothing,
      zio.aws.comprehend.model.DocumentClassifierInputDataConfig.ReadOnly
    ] = ZIO.succeed(inputDataConfig)
    def getOutputDataConfig: ZIO[
      Any,
      AwsError,
      zio.aws.comprehend.model.DocumentClassifierOutputDataConfig.ReadOnly
    ] = AwsError.unwrapOptionField("outputDataConfig", outputDataConfig)
    def getClientRequestToken: ZIO[Any, AwsError, ClientRequestTokenString] =
      AwsError.unwrapOptionField("clientRequestToken", clientRequestToken)
    def getLanguageCode
        : ZIO[Any, Nothing, zio.aws.comprehend.model.LanguageCode] =
      ZIO.succeed(languageCode)
    def getVolumeKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("volumeKmsKeyId", volumeKmsKeyId)
    def getVpcConfig
        : ZIO[Any, AwsError, zio.aws.comprehend.model.VpcConfig.ReadOnly] =
      AwsError.unwrapOptionField("vpcConfig", vpcConfig)
    def getMode
        : ZIO[Any, AwsError, zio.aws.comprehend.model.DocumentClassifierMode] =
      AwsError.unwrapOptionField("mode", mode)
    def getModelKmsKeyId: ZIO[Any, AwsError, KmsKeyId] =
      AwsError.unwrapOptionField("modelKmsKeyId", modelKmsKeyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest
  ) extends zio.aws.comprehend.model.CreateDocumentClassifierRequest.ReadOnly {
    override val documentClassifierName: ComprehendArnName =
      zio.aws.comprehend.model.primitives
        .ComprehendArnName(impl.documentClassifierName())
    override val versionName: Option[VersionName] = scala
      .Option(impl.versionName())
      .map(value => zio.aws.comprehend.model.primitives.VersionName(value))
    override val dataAccessRoleArn: IamRoleArn =
      zio.aws.comprehend.model.primitives.IamRoleArn(impl.dataAccessRoleArn())
    override val tags: Option[List[zio.aws.comprehend.model.Tag.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.comprehend.model.Tag.wrap(item)
          }.toList
        )
    override val inputDataConfig
        : zio.aws.comprehend.model.DocumentClassifierInputDataConfig.ReadOnly =
      zio.aws.comprehend.model.DocumentClassifierInputDataConfig
        .wrap(impl.inputDataConfig())
    override val outputDataConfig: Option[
      zio.aws.comprehend.model.DocumentClassifierOutputDataConfig.ReadOnly
    ] = scala
      .Option(impl.outputDataConfig())
      .map(value =>
        zio.aws.comprehend.model.DocumentClassifierOutputDataConfig.wrap(value)
      )
    override val clientRequestToken: Option[ClientRequestTokenString] = scala
      .Option(impl.clientRequestToken())
      .map(value =>
        zio.aws.comprehend.model.primitives.ClientRequestTokenString(value)
      )
    override val languageCode: zio.aws.comprehend.model.LanguageCode =
      zio.aws.comprehend.model.LanguageCode.wrap(impl.languageCode())
    override val volumeKmsKeyId: Option[KmsKeyId] = scala
      .Option(impl.volumeKmsKeyId())
      .map(value => zio.aws.comprehend.model.primitives.KmsKeyId(value))
    override val vpcConfig
        : Option[zio.aws.comprehend.model.VpcConfig.ReadOnly] = scala
      .Option(impl.vpcConfig())
      .map(value => zio.aws.comprehend.model.VpcConfig.wrap(value))
    override val mode: Option[zio.aws.comprehend.model.DocumentClassifierMode] =
      scala
        .Option(impl.mode())
        .map(value =>
          zio.aws.comprehend.model.DocumentClassifierMode.wrap(value)
        )
    override val modelKmsKeyId: Option[KmsKeyId] = scala
      .Option(impl.modelKmsKeyId())
      .map(value => zio.aws.comprehend.model.primitives.KmsKeyId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.CreateDocumentClassifierRequest
  ): zio.aws.comprehend.model.CreateDocumentClassifierRequest.ReadOnly =
    new Wrapper(impl)
}
